#!/bin/sh

#initialisation
. `dirname $0`/init.sh

rm ${OUT}/tmp.csv
rm ${OUT}/tmp.qif

squishrun tst_import_export
rc=$?
if [ $rc != 0 ] ; then
	exit $rc
fi

exit 0